==> http-infra-1.2.13.tgz: package/lib/request.js <==
'use strict';

const rp = require('request-promise');
const request = require('request');
const { getRequestId, getAuthenticatedEntity, getSourceIp } = require('./correlation');
const { REQUEST_ID_HEADER, AUTHENTICATED_ENTITY_HEADER, SOURCE_IP } = require('./headers');
const _ = require('lodash');

function serviceRequest(opt) {
    opt = opt || {};

    const serviceConfig = opt.serviceConfig;
    if (!serviceConfig) {
        throw new Error('Service config not provided');
    }
    const serviceBasePath = `${serviceConfig.protocol}://${serviceConfig.uri}:${serviceConfig.port}`;
    const path = opt.path;
    const requestOptions = opt.requestOptions || {};
    const headers = Object.assign({}, requestOptions.headers);

    // overriding the authenticated entity is something that should only be done in rare rare cases
    // please advise and discuss before overriding it
    const authenticatedEntity = opt.authenticatedEntity || getAuthenticatedEntity();
    if (authenticatedEntity) {
        headers[AUTHENTICATED_ENTITY_HEADER] =
            authenticatedEntity.encodeToBase64String();
    }
    const requestId = getRequestId();
    if (requestId) {
        headers[REQUEST_ID_HEADER] = requestId;
    }

    const sourceIp = getSourceIp();

    if (sourceIp) {
        headers[SOURCE_IP] = sourceIp;
    }

    const systemOptions = {
        url: `${serviceBasePath}${path}`,
        headers
    };

    if (opt.stream) {
        return request(systemOptions);
    } else {
        systemOptions.resolveWithFullResponse = true;
        systemOptions.json = true;
        return rp(Object.assign({}, requestOptions, systemOptions))
            .catch((err) => {
                const errorCode = _.get(err, 'error.code');
                const statusCode = _.get(err, 'statusCode');
                if (_.isEqual(errorCode, 'EAI_AGAIN') || _.isEqual(errorCode, 'ENOTFOUND') || statusCode === 502 || statusCode === 504) {
                    throw new Error('Service Unavailable');
                }
                throw err;
            });
    }
}

module.exports = serviceRequest;

==> http-infra-1.3.0.tgz: package/lib/request.js <==
'use strict';

const rp = require('request-promise');
const request = require('request');
const { getRequestId, getAuthenticatedEntity } = require('./correlation');
const { REQUEST_ID_HEADER, AUTHENTICATED_ENTITY_HEADER } = require('./headers');
const _ = require('lodash');

function serviceRequest(opt) {
    opt = opt || {};

    const serviceConfig = opt.serviceConfig;
    if (!serviceConfig) {
        throw new Error('Service config not provided');
    }
    const serviceBasePath = `${serviceConfig.protocol}://${serviceConfig.uri}:${serviceConfig.port}`;
    const path = opt.path;
    const requestOptions = opt.requestOptions || {};
    const headers = Object.assign({}, requestOptions.headers);

    // overriding the authenticated entity is something that should only be done in rare rare cases
    // please advise and discuss before overriding it
    const authenticatedEntity = opt.authenticatedEntity || getAuthenticatedEntity();
    if (authenticatedEntity) {
        headers[AUTHENTICATED_ENTITY_HEADER] =
            authenticatedEntity.encodeToBase64String();
    }
    const requestId = getRequestId();
    if (requestId) {
        headers[REQUEST_ID_HEADER] = requestId;
    }

    const systemOptions = {
        url: `${serviceBasePath}${path}`,
        headers
    };

    if (opt.stream) {
        return request(systemOptions);
    } else {
        systemOptions.resolveWithFullResponse = true;
        systemOptions.json = true;
        return rp(Object.assign({}, requestOptions, systemOptions))
            .catch((err) => {
                const errorCode = _.get(err, 'error.code');
                const statusCode = _.get(err, 'statusCode');
                if (_.isEqual(errorCode, 'EAI_AGAIN') || _.isEqual(errorCode, 'ENOTFOUND') || _.isEqual(errorCode, 'ECONNREFUSED') || statusCode === 502 || statusCode === 504) {
                    throw new Error('Service Unavailable');
                }
                throw err;
            });
    }
}

module.exports = serviceRequest;
